Enum TsThisTypeOrIdent
#[repr(u32)]pub enum TsThisTypeOrIdent {
TsThisType(TsThisType),
Ident(Ident),
}__ecma and __visit only.Variants
TsThisType(TsThisType)
Ident(Ident)
Implementations
impl TsThisTypeOrIdent
impl TsThisTypeOrIdent
pub const fn is_ts_this_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_this_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsThisType.
pub fn as_ts_this_type(&self) -> Option<&TsThisType>
Available on crate feature ecma_ast only.
pub fn as_ts_this_type(&self) -> Option<&TsThisType>
ecma_ast only.Returns Some if self is a reference of variant TsThisType, and None otherwise.
pub fn as_mut_ts_this_type(&mut self) -> Option<&mut TsThisType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_this_type(&mut self) -> Option<&mut TsThisType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsThisType, and None otherwise.
pub fn expect_ts_this_type(self) -> TsThisTypewhere
TsThisTypeOrIdent: Debug,
Available on crate feature ecma_ast only.
pub fn expect_ts_this_type(self) -> TsThisTypewhere
TsThisTypeOrIdent: Debug,
ecma_ast only.Unwraps the value, yielding the content of TsThisType.
Panics
Panics if the value is not TsThisType, with a panic message including the content of self.
pub fn ts_this_type(self) -> Option<TsThisType>
Available on crate feature ecma_ast only.
pub fn ts_this_type(self) -> Option<TsThisType>
ecma_ast only.Returns Some if self is of variant TsThisType, and None otherwise.
pub const fn is_ident(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ident(&self) -> bool
ecma_ast only.Returns true if self is of variant Ident.
pub fn as_ident(&self) -> Option<&Ident>
Available on crate feature ecma_ast only.
pub fn as_ident(&self) -> Option<&Ident>
ecma_ast only.Returns Some if self is a reference of variant Ident, and None otherwise.
pub fn as_mut_ident(&mut self) -> Option<&mut Ident>
Available on crate feature ecma_ast only.
pub fn as_mut_ident(&mut self) -> Option<&mut Ident>
ecma_ast only.Returns Some if self is a mutable reference of variant Ident, and None otherwise.
pub fn expect_ident(self) -> Identwhere
TsThisTypeOrIdent: Debug,
Available on crate feature ecma_ast only.
pub fn expect_ident(self) -> Identwhere
TsThisTypeOrIdent: Debug,
ecma_ast only.Trait Implementations
impl Archive for TsThisTypeOrIdent
impl Archive for TsThisTypeOrIdent
type Archived = ArchivedTsThisTypeOrIdent
type Archived = ArchivedTsThisTypeOrIdent
type Resolver = TsThisTypeOrIdentResolver
type Resolver = TsThisTypeOrIdentResolver
fn resolve(
&self,
resolver: <TsThisTypeOrIdent as Archive>::Resolver,
out: Place<<TsThisTypeOrIdent as Archive>::Archived>,
)
fn resolve( &self, resolver: <TsThisTypeOrIdent as Archive>::Resolver, out: Place<<TsThisTypeOrIdent as Archive>::Archived>, )
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
serialize. Read moreimpl Clone for TsThisTypeOrIdent
impl Clone for TsThisTypeOrIdent
fn clone(&self) -> TsThisTypeOrIdent
fn clone(&self) -> TsThisTypeOrIdent
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for TsThisTypeOrIdent
impl Debug for TsThisTypeOrIdent
impl<'de> Deserialize<'de> for TsThisTypeOrIdent
impl<'de> Deserialize<'de> for TsThisTypeOrIdent
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TsThisTypeOrIdent, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TsThisTypeOrIdent, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl<__D> Deserialize<TsThisTypeOrIdent, __D> for <TsThisTypeOrIdent as Archive>::Archivedwhere
__D: Fallible + ?Sized,
<__D as Fallible>::Error: Source,
impl<__D> Deserialize<TsThisTypeOrIdent, __D> for <TsThisTypeOrIdent as Archive>::Archivedwhere
__D: Fallible + ?Sized,
<__D as Fallible>::Error: Source,
fn deserialize(
&self,
deserializer: &mut __D,
) -> Result<TsThisTypeOrIdent, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<TsThisTypeOrIdent, <__D as Fallible>::Error>
impl EqIgnoreSpan for TsThisTypeOrIdent
impl EqIgnoreSpan for TsThisTypeOrIdent
fn eq_ignore_span(&self, other: &TsThisTypeOrIdent) -> bool
impl<V> FoldWith<V> for TsThisTypeOrIdent
impl<V> FoldWith<V> for TsThisTypeOrIdent
fn fold_with(self, visitor: &mut V) -> TsThisTypeOrIdent
fn fold_with(self, visitor: &mut V) -> TsThisTypeOrIdent
Calls Fold::fold_ts_this_type_or_ident with self.
fn fold_children_with(self, visitor: &mut V) -> TsThisTypeOrIdent
fn fold_children_with(self, visitor: &mut V) -> TsThisTypeOrIdent
self`` with visitor`.impl<'ast> From<&'ast TsThisTypeOrIdent> for NodeRef<'ast>
impl<'ast> From<&'ast TsThisTypeOrIdent> for NodeRef<'ast>
fn from(node: &'ast TsThisTypeOrIdent) -> NodeRef<'ast>
fn from(node: &'ast TsThisTypeOrIdent) -> NodeRef<'ast>
impl From<Ident> for TsThisTypeOrIdent
impl From<Ident> for TsThisTypeOrIdent
fn from(v: Ident) -> TsThisTypeOrIdent
fn from(v: Ident) -> TsThisTypeOrIdent
impl From<TsThisType> for TsThisTypeOrIdent
impl From<TsThisType> for TsThisTypeOrIdent
fn from(v: TsThisType) -> TsThisTypeOrIdent
fn from(v: TsThisType) -> TsThisTypeOrIdent
impl Hash for TsThisTypeOrIdent
impl Hash for TsThisTypeOrIdent
impl Node for TsThisTypeOrIdent
impl Node for TsThisTypeOrIdent
fn emit_with<W, S>(&self, emitter: &mut Emitter<'_, W, S>) -> Result<(), Error>where
W: WriteJs,
S: SourceMapper + SourceMapperExt,
impl PartialEq for TsThisTypeOrIdent
impl PartialEq for TsThisTypeOrIdent
impl<__S> Serialize<__S> for TsThisTypeOrIdentwhere
__S: Fallible + Writer + Allocator + ?Sized,
<__S as Fallible>::Error: Source,
impl<__S> Serialize<__S> for TsThisTypeOrIdentwhere
__S: Fallible + Writer + Allocator + ?Sized,
<__S as Fallible>::Error: Source,
fn serialize(
&self,
serializer: &mut __S,
) -> Result<<TsThisTypeOrIdent as Archive>::Resolver, <__S as Fallible>::Error>
fn serialize( &self, serializer: &mut __S, ) -> Result<<TsThisTypeOrIdent as Archive>::Resolver, <__S as Fallible>::Error>
impl Serialize for TsThisTypeOrIdent
impl Serialize for TsThisTypeOrIdent
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl Spanned for TsThisTypeOrIdent
impl Spanned for TsThisTypeOrIdent
impl<V> VisitMutWith<V> for TsThisTypeOrIdent
impl<V> VisitMutWith<V> for TsThisTypeOrIdent
fn visit_mut_with(&mut self, visitor: &mut V)
fn visit_mut_with(&mut self, visitor: &mut V)
Calls VisitMut::visit_mut_ts_this_type_or_ident with self.
fn visit_mut_children_with(&mut self, visitor: &mut V)
fn visit_mut_children_with(&mut self, visitor: &mut V)
self`` with visitor`.impl<V> VisitWith<V> for TsThisTypeOrIdent
impl<V> VisitWith<V> for TsThisTypeOrIdent
fn visit_with(&self, visitor: &mut V)
fn visit_with(&self, visitor: &mut V)
Calls Visit::visit_ts_this_type_or_ident with self.
fn visit_children_with(&self, visitor: &mut V)
fn visit_children_with(&self, visitor: &mut V)
self`` with visitor`.impl Eq for TsThisTypeOrIdent
impl StructuralPartialEq for TsThisTypeOrIdent