Enum TsType
#[repr(u32)]pub enum TsType {
Show 20 variants
TsKeywordType(TsKeywordType),
TsThisType(TsThisType),
TsFnOrConstructorType(TsFnOrConstructorType),
TsTypeRef(TsTypeRef),
TsTypeQuery(TsTypeQuery),
TsTypeLit(TsTypeLit),
TsArrayType(TsArrayType),
TsTupleType(TsTupleType),
TsOptionalType(TsOptionalType),
TsRestType(TsRestType),
TsUnionOrIntersectionType(TsUnionOrIntersectionType),
TsConditionalType(TsConditionalType),
TsInferType(TsInferType),
TsParenthesizedType(TsParenthesizedType),
TsTypeOperator(TsTypeOperator),
TsIndexedAccessType(TsIndexedAccessType),
TsMappedType(TsMappedType),
TsLitType(TsLitType),
TsTypePredicate(TsTypePredicate),
TsImportType(TsImportType),
}__ecma and __visit only.Variants
TsKeywordType(TsKeywordType)
TsThisType(TsThisType)
TsFnOrConstructorType(TsFnOrConstructorType)
TsTypeRef(TsTypeRef)
TsTypeQuery(TsTypeQuery)
TsTypeLit(TsTypeLit)
TsArrayType(TsArrayType)
TsTupleType(TsTupleType)
TsOptionalType(TsOptionalType)
TsRestType(TsRestType)
TsUnionOrIntersectionType(TsUnionOrIntersectionType)
TsConditionalType(TsConditionalType)
TsInferType(TsInferType)
TsParenthesizedType(TsParenthesizedType)
TsTypeOperator(TsTypeOperator)
TsIndexedAccessType(TsIndexedAccessType)
TsMappedType(TsMappedType)
TsLitType(TsLitType)
TsTypePredicate(TsTypePredicate)
TsImportType(TsImportType)
Implementations
impl TsType
impl TsType
pub const fn is_ts_keyword_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_keyword_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsKeywordType.
pub fn as_ts_keyword_type(&self) -> Option<&TsKeywordType>
Available on crate feature ecma_ast only.
pub fn as_ts_keyword_type(&self) -> Option<&TsKeywordType>
ecma_ast only.Returns Some if self is a reference of variant TsKeywordType, and None otherwise.
pub fn as_mut_ts_keyword_type(&mut self) -> Option<&mut TsKeywordType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_keyword_type(&mut self) -> Option<&mut TsKeywordType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsKeywordType, and None otherwise.
pub fn expect_ts_keyword_type(self) -> TsKeywordType
Available on crate feature ecma_ast only.
pub fn expect_ts_keyword_type(self) -> TsKeywordType
ecma_ast only.Unwraps the value, yielding the content of TsKeywordType.
Panics
Panics if the value is not TsKeywordType, with a panic message including the content of self.
pub fn ts_keyword_type(self) -> Option<TsKeywordType>
Available on crate feature ecma_ast only.
pub fn ts_keyword_type(self) -> Option<TsKeywordType>
ecma_ast only.Returns Some if self is of variant TsKeywordType, and None otherwise.
pub const fn is_ts_this_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_this_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsThisType.
pub fn as_ts_this_type(&self) -> Option<&TsThisType>
Available on crate feature ecma_ast only.
pub fn as_ts_this_type(&self) -> Option<&TsThisType>
ecma_ast only.Returns Some if self is a reference of variant TsThisType, and None otherwise.
pub fn as_mut_ts_this_type(&mut self) -> Option<&mut TsThisType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_this_type(&mut self) -> Option<&mut TsThisType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsThisType, and None otherwise.
pub fn expect_ts_this_type(self) -> TsThisType
Available on crate feature ecma_ast only.
pub fn expect_ts_this_type(self) -> TsThisType
ecma_ast only.Unwraps the value, yielding the content of TsThisType.
Panics
Panics if the value is not TsThisType, with a panic message including the content of self.
pub fn ts_this_type(self) -> Option<TsThisType>
Available on crate feature ecma_ast only.
pub fn ts_this_type(self) -> Option<TsThisType>
ecma_ast only.Returns Some if self is of variant TsThisType, and None otherwise.
pub const fn is_ts_fn_or_constructor_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_fn_or_constructor_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsFnOrConstructorType.
pub fn as_ts_fn_or_constructor_type(&self) -> Option<&TsFnOrConstructorType>
Available on crate feature ecma_ast only.
pub fn as_ts_fn_or_constructor_type(&self) -> Option<&TsFnOrConstructorType>
ecma_ast only.Returns Some if self is a reference of variant TsFnOrConstructorType, and None otherwise.
pub fn as_mut_ts_fn_or_constructor_type(
&mut self,
) -> Option<&mut TsFnOrConstructorType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_fn_or_constructor_type( &mut self, ) -> Option<&mut TsFnOrConstructorType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsFnOrConstructorType, and None otherwise.
pub fn expect_ts_fn_or_constructor_type(self) -> TsFnOrConstructorType
Available on crate feature ecma_ast only.
pub fn expect_ts_fn_or_constructor_type(self) -> TsFnOrConstructorType
ecma_ast only.Unwraps the value, yielding the content of TsFnOrConstructorType.
Panics
Panics if the value is not TsFnOrConstructorType, with a panic message including the content of self.
pub fn ts_fn_or_constructor_type(self) -> Option<TsFnOrConstructorType>
Available on crate feature ecma_ast only.
pub fn ts_fn_or_constructor_type(self) -> Option<TsFnOrConstructorType>
ecma_ast only.Returns Some if self is of variant TsFnOrConstructorType, and None otherwise.
pub const fn is_ts_type_ref(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_type_ref(&self) -> bool
ecma_ast only.Returns true if self is of variant TsTypeRef.
pub fn as_ts_type_ref(&self) -> Option<&TsTypeRef>
Available on crate feature ecma_ast only.
pub fn as_ts_type_ref(&self) -> Option<&TsTypeRef>
ecma_ast only.Returns Some if self is a reference of variant TsTypeRef, and None otherwise.
pub fn as_mut_ts_type_ref(&mut self) -> Option<&mut TsTypeRef>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_type_ref(&mut self) -> Option<&mut TsTypeRef>
ecma_ast only.Returns Some if self is a mutable reference of variant TsTypeRef, and None otherwise.
pub fn expect_ts_type_ref(self) -> TsTypeRef
Available on crate feature ecma_ast only.
pub fn expect_ts_type_ref(self) -> TsTypeRef
ecma_ast only.pub fn ts_type_ref(self) -> Option<TsTypeRef>
Available on crate feature ecma_ast only.
pub fn ts_type_ref(self) -> Option<TsTypeRef>
ecma_ast only.Returns Some if self is of variant TsTypeRef, and None otherwise.
pub const fn is_ts_type_query(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_type_query(&self) -> bool
ecma_ast only.Returns true if self is of variant TsTypeQuery.
pub fn as_ts_type_query(&self) -> Option<&TsTypeQuery>
Available on crate feature ecma_ast only.
pub fn as_ts_type_query(&self) -> Option<&TsTypeQuery>
ecma_ast only.Returns Some if self is a reference of variant TsTypeQuery, and None otherwise.
pub fn as_mut_ts_type_query(&mut self) -> Option<&mut TsTypeQuery>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_type_query(&mut self) -> Option<&mut TsTypeQuery>
ecma_ast only.Returns Some if self is a mutable reference of variant TsTypeQuery, and None otherwise.
pub fn expect_ts_type_query(self) -> TsTypeQuery
Available on crate feature ecma_ast only.
pub fn expect_ts_type_query(self) -> TsTypeQuery
ecma_ast only.Unwraps the value, yielding the content of TsTypeQuery.
Panics
Panics if the value is not TsTypeQuery, with a panic message including the content of self.
pub fn ts_type_query(self) -> Option<TsTypeQuery>
Available on crate feature ecma_ast only.
pub fn ts_type_query(self) -> Option<TsTypeQuery>
ecma_ast only.Returns Some if self is of variant TsTypeQuery, and None otherwise.
pub const fn is_ts_type_lit(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_type_lit(&self) -> bool
ecma_ast only.Returns true if self is of variant TsTypeLit.
pub fn as_ts_type_lit(&self) -> Option<&TsTypeLit>
Available on crate feature ecma_ast only.
pub fn as_ts_type_lit(&self) -> Option<&TsTypeLit>
ecma_ast only.Returns Some if self is a reference of variant TsTypeLit, and None otherwise.
pub fn as_mut_ts_type_lit(&mut self) -> Option<&mut TsTypeLit>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_type_lit(&mut self) -> Option<&mut TsTypeLit>
ecma_ast only.Returns Some if self is a mutable reference of variant TsTypeLit, and None otherwise.
pub fn expect_ts_type_lit(self) -> TsTypeLit
Available on crate feature ecma_ast only.
pub fn expect_ts_type_lit(self) -> TsTypeLit
ecma_ast only.pub fn ts_type_lit(self) -> Option<TsTypeLit>
Available on crate feature ecma_ast only.
pub fn ts_type_lit(self) -> Option<TsTypeLit>
ecma_ast only.Returns Some if self is of variant TsTypeLit, and None otherwise.
pub const fn is_ts_array_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_array_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsArrayType.
pub fn as_ts_array_type(&self) -> Option<&TsArrayType>
Available on crate feature ecma_ast only.
pub fn as_ts_array_type(&self) -> Option<&TsArrayType>
ecma_ast only.Returns Some if self is a reference of variant TsArrayType, and None otherwise.
pub fn as_mut_ts_array_type(&mut self) -> Option<&mut TsArrayType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_array_type(&mut self) -> Option<&mut TsArrayType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsArrayType, and None otherwise.
pub fn expect_ts_array_type(self) -> TsArrayType
Available on crate feature ecma_ast only.
pub fn expect_ts_array_type(self) -> TsArrayType
ecma_ast only.Unwraps the value, yielding the content of TsArrayType.
Panics
Panics if the value is not TsArrayType, with a panic message including the content of self.
pub fn ts_array_type(self) -> Option<TsArrayType>
Available on crate feature ecma_ast only.
pub fn ts_array_type(self) -> Option<TsArrayType>
ecma_ast only.Returns Some if self is of variant TsArrayType, and None otherwise.
pub const fn is_ts_tuple_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_tuple_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsTupleType.
pub fn as_ts_tuple_type(&self) -> Option<&TsTupleType>
Available on crate feature ecma_ast only.
pub fn as_ts_tuple_type(&self) -> Option<&TsTupleType>
ecma_ast only.Returns Some if self is a reference of variant TsTupleType, and None otherwise.
pub fn as_mut_ts_tuple_type(&mut self) -> Option<&mut TsTupleType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_tuple_type(&mut self) -> Option<&mut TsTupleType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsTupleType, and None otherwise.
pub fn expect_ts_tuple_type(self) -> TsTupleType
Available on crate feature ecma_ast only.
pub fn expect_ts_tuple_type(self) -> TsTupleType
ecma_ast only.Unwraps the value, yielding the content of TsTupleType.
Panics
Panics if the value is not TsTupleType, with a panic message including the content of self.
pub fn ts_tuple_type(self) -> Option<TsTupleType>
Available on crate feature ecma_ast only.
pub fn ts_tuple_type(self) -> Option<TsTupleType>
ecma_ast only.Returns Some if self is of variant TsTupleType, and None otherwise.
pub const fn is_ts_optional_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_optional_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsOptionalType.
pub fn as_ts_optional_type(&self) -> Option<&TsOptionalType>
Available on crate feature ecma_ast only.
pub fn as_ts_optional_type(&self) -> Option<&TsOptionalType>
ecma_ast only.Returns Some if self is a reference of variant TsOptionalType, and None otherwise.
pub fn as_mut_ts_optional_type(&mut self) -> Option<&mut TsOptionalType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_optional_type(&mut self) -> Option<&mut TsOptionalType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsOptionalType, and None otherwise.
pub fn expect_ts_optional_type(self) -> TsOptionalType
Available on crate feature ecma_ast only.
pub fn expect_ts_optional_type(self) -> TsOptionalType
ecma_ast only.Unwraps the value, yielding the content of TsOptionalType.
Panics
Panics if the value is not TsOptionalType, with a panic message including the content of self.
pub fn ts_optional_type(self) -> Option<TsOptionalType>
Available on crate feature ecma_ast only.
pub fn ts_optional_type(self) -> Option<TsOptionalType>
ecma_ast only.Returns Some if self is of variant TsOptionalType, and None otherwise.
pub const fn is_ts_rest_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_rest_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsRestType.
pub fn as_ts_rest_type(&self) -> Option<&TsRestType>
Available on crate feature ecma_ast only.
pub fn as_ts_rest_type(&self) -> Option<&TsRestType>
ecma_ast only.Returns Some if self is a reference of variant TsRestType, and None otherwise.
pub fn as_mut_ts_rest_type(&mut self) -> Option<&mut TsRestType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_rest_type(&mut self) -> Option<&mut TsRestType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsRestType, and None otherwise.
pub fn expect_ts_rest_type(self) -> TsRestType
Available on crate feature ecma_ast only.
pub fn expect_ts_rest_type(self) -> TsRestType
ecma_ast only.Unwraps the value, yielding the content of TsRestType.
Panics
Panics if the value is not TsRestType, with a panic message including the content of self.
pub fn ts_rest_type(self) -> Option<TsRestType>
Available on crate feature ecma_ast only.
pub fn ts_rest_type(self) -> Option<TsRestType>
ecma_ast only.Returns Some if self is of variant TsRestType, and None otherwise.
pub const fn is_ts_union_or_intersection_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_union_or_intersection_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsUnionOrIntersectionType.
pub fn as_ts_union_or_intersection_type(
&self,
) -> Option<&TsUnionOrIntersectionType>
Available on crate feature ecma_ast only.
pub fn as_ts_union_or_intersection_type( &self, ) -> Option<&TsUnionOrIntersectionType>
ecma_ast only.Returns Some if self is a reference of variant TsUnionOrIntersectionType, and None otherwise.
pub fn as_mut_ts_union_or_intersection_type(
&mut self,
) -> Option<&mut TsUnionOrIntersectionType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_union_or_intersection_type( &mut self, ) -> Option<&mut TsUnionOrIntersectionType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsUnionOrIntersectionType, and None otherwise.
pub fn expect_ts_union_or_intersection_type(self) -> TsUnionOrIntersectionType
Available on crate feature ecma_ast only.
pub fn expect_ts_union_or_intersection_type(self) -> TsUnionOrIntersectionType
ecma_ast only.Unwraps the value, yielding the content of TsUnionOrIntersectionType.
Panics
Panics if the value is not TsUnionOrIntersectionType, with a panic message including the content of self.
pub fn ts_union_or_intersection_type(self) -> Option<TsUnionOrIntersectionType>
Available on crate feature ecma_ast only.
pub fn ts_union_or_intersection_type(self) -> Option<TsUnionOrIntersectionType>
ecma_ast only.Returns Some if self is of variant TsUnionOrIntersectionType, and None otherwise.
pub const fn is_ts_conditional_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_conditional_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsConditionalType.
pub fn as_ts_conditional_type(&self) -> Option<&TsConditionalType>
Available on crate feature ecma_ast only.
pub fn as_ts_conditional_type(&self) -> Option<&TsConditionalType>
ecma_ast only.Returns Some if self is a reference of variant TsConditionalType, and None otherwise.
pub fn as_mut_ts_conditional_type(&mut self) -> Option<&mut TsConditionalType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_conditional_type(&mut self) -> Option<&mut TsConditionalType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsConditionalType, and None otherwise.
pub fn expect_ts_conditional_type(self) -> TsConditionalType
Available on crate feature ecma_ast only.
pub fn expect_ts_conditional_type(self) -> TsConditionalType
ecma_ast only.Unwraps the value, yielding the content of TsConditionalType.
Panics
Panics if the value is not TsConditionalType, with a panic message including the content of self.
pub fn ts_conditional_type(self) -> Option<TsConditionalType>
Available on crate feature ecma_ast only.
pub fn ts_conditional_type(self) -> Option<TsConditionalType>
ecma_ast only.Returns Some if self is of variant TsConditionalType, and None otherwise.
pub const fn is_ts_infer_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_infer_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsInferType.
pub fn as_ts_infer_type(&self) -> Option<&TsInferType>
Available on crate feature ecma_ast only.
pub fn as_ts_infer_type(&self) -> Option<&TsInferType>
ecma_ast only.Returns Some if self is a reference of variant TsInferType, and None otherwise.
pub fn as_mut_ts_infer_type(&mut self) -> Option<&mut TsInferType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_infer_type(&mut self) -> Option<&mut TsInferType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsInferType, and None otherwise.
pub fn expect_ts_infer_type(self) -> TsInferType
Available on crate feature ecma_ast only.
pub fn expect_ts_infer_type(self) -> TsInferType
ecma_ast only.Unwraps the value, yielding the content of TsInferType.
Panics
Panics if the value is not TsInferType, with a panic message including the content of self.
pub fn ts_infer_type(self) -> Option<TsInferType>
Available on crate feature ecma_ast only.
pub fn ts_infer_type(self) -> Option<TsInferType>
ecma_ast only.Returns Some if self is of variant TsInferType, and None otherwise.
pub const fn is_ts_parenthesized_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_parenthesized_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsParenthesizedType.
pub fn as_ts_parenthesized_type(&self) -> Option<&TsParenthesizedType>
Available on crate feature ecma_ast only.
pub fn as_ts_parenthesized_type(&self) -> Option<&TsParenthesizedType>
ecma_ast only.Returns Some if self is a reference of variant TsParenthesizedType, and None otherwise.
pub fn as_mut_ts_parenthesized_type(
&mut self,
) -> Option<&mut TsParenthesizedType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_parenthesized_type( &mut self, ) -> Option<&mut TsParenthesizedType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsParenthesizedType, and None otherwise.
pub fn expect_ts_parenthesized_type(self) -> TsParenthesizedType
Available on crate feature ecma_ast only.
pub fn expect_ts_parenthesized_type(self) -> TsParenthesizedType
ecma_ast only.Unwraps the value, yielding the content of TsParenthesizedType.
Panics
Panics if the value is not TsParenthesizedType, with a panic message including the content of self.
pub fn ts_parenthesized_type(self) -> Option<TsParenthesizedType>
Available on crate feature ecma_ast only.
pub fn ts_parenthesized_type(self) -> Option<TsParenthesizedType>
ecma_ast only.Returns Some if self is of variant TsParenthesizedType, and None otherwise.
pub const fn is_ts_type_operator(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_type_operator(&self) -> bool
ecma_ast only.Returns true if self is of variant TsTypeOperator.
pub fn as_ts_type_operator(&self) -> Option<&TsTypeOperator>
Available on crate feature ecma_ast only.
pub fn as_ts_type_operator(&self) -> Option<&TsTypeOperator>
ecma_ast only.Returns Some if self is a reference of variant TsTypeOperator, and None otherwise.
pub fn as_mut_ts_type_operator(&mut self) -> Option<&mut TsTypeOperator>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_type_operator(&mut self) -> Option<&mut TsTypeOperator>
ecma_ast only.Returns Some if self is a mutable reference of variant TsTypeOperator, and None otherwise.
pub fn expect_ts_type_operator(self) -> TsTypeOperator
Available on crate feature ecma_ast only.
pub fn expect_ts_type_operator(self) -> TsTypeOperator
ecma_ast only.Unwraps the value, yielding the content of TsTypeOperator.
Panics
Panics if the value is not TsTypeOperator, with a panic message including the content of self.
pub fn ts_type_operator(self) -> Option<TsTypeOperator>
Available on crate feature ecma_ast only.
pub fn ts_type_operator(self) -> Option<TsTypeOperator>
ecma_ast only.Returns Some if self is of variant TsTypeOperator, and None otherwise.
pub const fn is_ts_indexed_access_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_indexed_access_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsIndexedAccessType.
pub fn as_ts_indexed_access_type(&self) -> Option<&TsIndexedAccessType>
Available on crate feature ecma_ast only.
pub fn as_ts_indexed_access_type(&self) -> Option<&TsIndexedAccessType>
ecma_ast only.Returns Some if self is a reference of variant TsIndexedAccessType, and None otherwise.
pub fn as_mut_ts_indexed_access_type(
&mut self,
) -> Option<&mut TsIndexedAccessType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_indexed_access_type( &mut self, ) -> Option<&mut TsIndexedAccessType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsIndexedAccessType, and None otherwise.
pub fn expect_ts_indexed_access_type(self) -> TsIndexedAccessType
Available on crate feature ecma_ast only.
pub fn expect_ts_indexed_access_type(self) -> TsIndexedAccessType
ecma_ast only.Unwraps the value, yielding the content of TsIndexedAccessType.
Panics
Panics if the value is not TsIndexedAccessType, with a panic message including the content of self.
pub fn ts_indexed_access_type(self) -> Option<TsIndexedAccessType>
Available on crate feature ecma_ast only.
pub fn ts_indexed_access_type(self) -> Option<TsIndexedAccessType>
ecma_ast only.Returns Some if self is of variant TsIndexedAccessType, and None otherwise.
pub const fn is_ts_mapped_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_mapped_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsMappedType.
pub fn as_ts_mapped_type(&self) -> Option<&TsMappedType>
Available on crate feature ecma_ast only.
pub fn as_ts_mapped_type(&self) -> Option<&TsMappedType>
ecma_ast only.Returns Some if self is a reference of variant TsMappedType, and None otherwise.
pub fn as_mut_ts_mapped_type(&mut self) -> Option<&mut TsMappedType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_mapped_type(&mut self) -> Option<&mut TsMappedType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsMappedType, and None otherwise.
pub fn expect_ts_mapped_type(self) -> TsMappedType
Available on crate feature ecma_ast only.
pub fn expect_ts_mapped_type(self) -> TsMappedType
ecma_ast only.Unwraps the value, yielding the content of TsMappedType.
Panics
Panics if the value is not TsMappedType, with a panic message including the content of self.
pub fn ts_mapped_type(self) -> Option<TsMappedType>
Available on crate feature ecma_ast only.
pub fn ts_mapped_type(self) -> Option<TsMappedType>
ecma_ast only.Returns Some if self is of variant TsMappedType, and None otherwise.
pub const fn is_ts_lit_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_lit_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsLitType.
pub fn as_ts_lit_type(&self) -> Option<&TsLitType>
Available on crate feature ecma_ast only.
pub fn as_ts_lit_type(&self) -> Option<&TsLitType>
ecma_ast only.Returns Some if self is a reference of variant TsLitType, and None otherwise.
pub fn as_mut_ts_lit_type(&mut self) -> Option<&mut TsLitType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_lit_type(&mut self) -> Option<&mut TsLitType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsLitType, and None otherwise.
pub fn expect_ts_lit_type(self) -> TsLitType
Available on crate feature ecma_ast only.
pub fn expect_ts_lit_type(self) -> TsLitType
ecma_ast only.pub fn ts_lit_type(self) -> Option<TsLitType>
Available on crate feature ecma_ast only.
pub fn ts_lit_type(self) -> Option<TsLitType>
ecma_ast only.Returns Some if self is of variant TsLitType, and None otherwise.
pub const fn is_ts_type_predicate(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_type_predicate(&self) -> bool
ecma_ast only.Returns true if self is of variant TsTypePredicate.
pub fn as_ts_type_predicate(&self) -> Option<&TsTypePredicate>
Available on crate feature ecma_ast only.
pub fn as_ts_type_predicate(&self) -> Option<&TsTypePredicate>
ecma_ast only.Returns Some if self is a reference of variant TsTypePredicate, and None otherwise.
pub fn as_mut_ts_type_predicate(&mut self) -> Option<&mut TsTypePredicate>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_type_predicate(&mut self) -> Option<&mut TsTypePredicate>
ecma_ast only.Returns Some if self is a mutable reference of variant TsTypePredicate, and None otherwise.
pub fn expect_ts_type_predicate(self) -> TsTypePredicate
Available on crate feature ecma_ast only.
pub fn expect_ts_type_predicate(self) -> TsTypePredicate
ecma_ast only.Unwraps the value, yielding the content of TsTypePredicate.
Panics
Panics if the value is not TsTypePredicate, with a panic message including the content of self.
pub fn ts_type_predicate(self) -> Option<TsTypePredicate>
Available on crate feature ecma_ast only.
pub fn ts_type_predicate(self) -> Option<TsTypePredicate>
ecma_ast only.Returns Some if self is of variant TsTypePredicate, and None otherwise.
pub const fn is_ts_import_type(&self) -> bool
Available on crate feature ecma_ast only.
pub const fn is_ts_import_type(&self) -> bool
ecma_ast only.Returns true if self is of variant TsImportType.
pub fn as_ts_import_type(&self) -> Option<&TsImportType>
Available on crate feature ecma_ast only.
pub fn as_ts_import_type(&self) -> Option<&TsImportType>
ecma_ast only.Returns Some if self is a reference of variant TsImportType, and None otherwise.
pub fn as_mut_ts_import_type(&mut self) -> Option<&mut TsImportType>
Available on crate feature ecma_ast only.
pub fn as_mut_ts_import_type(&mut self) -> Option<&mut TsImportType>
ecma_ast only.Returns Some if self is a mutable reference of variant TsImportType, and None otherwise.
pub fn expect_ts_import_type(self) -> TsImportType
Available on crate feature ecma_ast only.
pub fn expect_ts_import_type(self) -> TsImportType
ecma_ast only.Unwraps the value, yielding the content of TsImportType.
Panics
Panics if the value is not TsImportType, with a panic message including the content of self.
pub fn ts_import_type(self) -> Option<TsImportType>
Available on crate feature ecma_ast only.
pub fn ts_import_type(self) -> Option<TsImportType>
ecma_ast only.Returns Some if self is of variant TsImportType, and None otherwise.